@@ -1,11 +1,11 @@
 #' USGS Parameter Data Retrieval
 #'
 #' Imports data from NWIS about measured parameter based on user-supplied parameter code or codes.
-#' This function gets the data from here: \url{https://nwis.waterdata.usgs.gov/nwis/pmcodes}
+#' This function gets the data from here: <https://nwis.waterdata.usgs.gov/nwis/pmcodes>
 #'
-#' @param parameterCd character of USGS parameter codes (or multiple parameter codes).  These are 5 digit number codes,
-#' more information can be found here: \url{https://help.waterdata.usgs.gov/}. To get a
-#' complete list of all current parameter codes in the USGS, use "all" as the input.
+#' @param parameterCd character of USGS parameter codes (or multiple parameter codes).
+#' These are 5 digit number codes. To get a complete list of all current parameter
+#' codes in the USGS, use "all" as the input.
 #' @keywords data import USGS web service
 #' @return parameterData data frame with the following information:
 #' \tabular{lll}{
@@ -19,7 +19,7 @@
 #' }
 #'
 #' @export
-#' @seealso \code{\link{importRDB1}}
+#' @seealso [importRDB1()]
 #' @examples
 #'
 #' paramINFO <- readNWISpCode(c("01075", "00060", "00931"))
@@ -31,6 +31,9 @@
 #' 
 #' }
 readNWISpCode <- function(parameterCd) {
+  
+  message(new_nwis_message())
+  
   parameterCd.orig <- parameterCd
   parameterCd <- parameterCd[!is.na(parameterCd)]
   baseURL <- httr2::request(pkg.env[["pCode"]])
